@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::PERLANCAR::AddDeps;
 
 our $DATE = '2015-05-15'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -20,7 +20,7 @@ use Module::Path::More qw(module_path);
 has module => (is=>'rw');
 has include_author => (is=>'rw');
 
-sub mvp_multivalue_args { qw(include_author add_requires) }
+sub mvp_multivalue_args { qw(include_author module) }
 
 use namespace::autoclean;
 
@@ -118,7 +118,7 @@ Dist::Zilla::Plugin::PERLANCAR::AddDeps - Include dependencies into dist
 
 =head1 VERSION
 
-This document describes version 0.04 of Dist::Zilla::Plugin::PERLANCAR::AddDeps (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-AddDeps), released on 2015-05-15.
+This document describes version 0.05 of Dist::Zilla::Plugin::PERLANCAR::AddDeps (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-AddDeps), released on 2015-05-15.
 
 =head1 SYNOPSIS
 
